stringtools.is_underscore_delimited_lowercase_file_name
=======================================================

.. autofunction:: abjad.tools.stringtools.is_underscore_delimited_lowercase_file_name.is_underscore_delimited_lowercase_file_name
   :noindex:
